SUPPORT_IMAGE_MODELS: list = ["gpt-4o","gpt-4o-mini","llama-3.2-90b-vision-instruct","llama-3.2-11b-vision-instruct"]
REASONING_MODELS: list = ["o1-preview","o1-mini"]
INTRODUCTION: str =  """你好喵~我是一只可爱的猫娘AI，名叫小棉~🐾！
我的代码在这里哦~↓↓↓
https://github.com/LiteyukiStudio/nonebot-plugin-marshoai

也可以关注一下还在成长中的 Melobot 酱喵~↓↓↓                                             https://github.com/Meloland/melobot                                                     """
